| Title: | 'Quarto' Website Templates for Academics |
|---|---|
| Description: | Provides three 'Quarto' website templates as an R project, which are commonly used by academics. Templates for personal websites and course/workshop websites are included, as well as a template with minimal content for customization. |
| Authors: | Chi Zhang [aut, cre] (ORCID: <https://orcid.org/0000-0003-0501-5909>) |
| Maintainer: | Chi Zhang <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 2022.12.13 |
| Built: | 2026-05-11 06:30:11 UTC |
| Source: | https://github.com/chizapoth/qtwacademic |
This function makes an R project that includes 3 basic templates that are commonly used by academics.
make_qtw_template(path, template_option)make_qtw_template(path, template_option)
path |
Path of the R project |
template_option |
Template option to choose. |
Returns nothing.
## Not run: make_qtw_template(path = tempdir(), template_option = "Minimal") ## End(Not run)## Not run: make_qtw_template(path = tempdir(), template_option = "Minimal") ## End(Not run)