Welcome to ClientVPS Mirrors

Help for package qtwAcademic
Title: 'Quarto' Website Templates for Academics
Version: 2022.12.13
Description: Provides three 'Quarto' website templates as an R project, which are commonly used by academics. Templates for personal websites and course/workshop websites are included, as well as a template with minimal content for customization.
Depends: R (≥ 4.0.0)
Imports: fs
Suggests: knitr, rmarkdown
License: MIT + file LICENSE
URL: https://andreaczhang.github.io/qtwAcademic/, https://github.com/andreaczhang/qtwAcademic
BugReports: https://github.com/andreaczhang/qtwAcademic/issues
Encoding: UTF-8
RoxygenNote: 7.2.1
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2022-12-21 17:50:45 UTC; andrea
Author: Chi Zhang ORCID iD [aut, cre]
Maintainer: Chi Zhang <andreachizhang@yahoo.com>
Repository: CRAN
Date/Publication: 2022-12-22 20:00:05 UTC

Make Quarto Website template

Description

This function makes an R project that includes 3 basic templates that are commonly used by academics.

Usage

make_qtw_template(path, template_option)

Arguments

path

Path of the R project

template_option

Template option to choose.

Value

Returns nothing.

Examples

## Not run: 
  make_qtw_template(path = tempdir(), template_option = "Minimal")

## End(Not run)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.